==> haskell-aeson-better-errors-0.9.1.0-30-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-DPy5gHezRZzF0i5pWIE86
key: aeson-better-errors-0.9.1.0-DPy5gHezRZzF0i5pWIE86
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: 8ca4deb7364a273ffa75ec29fe406d57
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-DPy5gHezRZzF0i5pWIE86
depends:
    base-4.10.0.0 aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 void-0.7.2-KNNEd7XG9bDRysTndgnf2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=bfdecfdd320edc5290f0eb88b00ff7c3
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.0-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-6cjM3lN82VgEg365d8dDOy
key: aeson-better-errors-0.9.1.0-6cjM3lN82VgEg365d8dDOy
license: MIT
maintainer: harry@garrood.me
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
author: Harry Garrood
exposed: True
indefinite: False
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
abi: 991d5e1c6ded8c49b21ebd28527bc83e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-6cjM3lN82VgEg365d8dDOy
depends:
    base-4.10.0.0 aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi transformers-0.5.2.0
    transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 void-0.7.2-KNNEd7XG9bDRysTndgnf2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             transformers-compat-0.5.1.4-8ofY1OHzPhX5dvYk512o2v=cbaa4957cb14b8a9e85ebeab0ab7d6ba
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             void-0.7.2-KNNEd7XG9bDRysTndgnf2=bfdecfdd320edc5290f0eb88b00ff7c3
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
